package com.example.mymvvmdemo.base

import android.app.ProgressDialog
import android.os.Bundle
import android.util.Log
import androidx.databinding.ViewDataBinding
import com.example.common.base.fragment.BaseVmDbFragment
import com.example.common.base.viewmodel.BaseViewModel

/**
 * <pre>
 *     author : louis wang
 *     time   : 2020/06/22
 *     desc   :
 *     version: 1.0
 * </pre>
 */
abstract class BaseFragment<VM : BaseViewModel, DB : ViewDataBinding> : BaseVmDbFragment<VM, DB>() {

    lateinit var loading: ProgressDialog

    /**
     * 当前Fragment绑定的视图布局
     */
    abstract override fun layoutId(): Int


    abstract override fun initView(savedInstanceState: Bundle?)

    /**
     * 懒加载 只有当前fragment视图显示时才会触发该方法
     */
    override fun lazyLoadData() {}

    /**
     * 创建LiveData观察者 Fragment执行onViewCreated后触发
     */
    abstract override fun createObserver()


    /**
     * Fragment执行onViewCreated后触发
     */
    override fun initData() {

    }

    override fun showLoading(message: String) {
        if (!::loading.isInitialized) {
            loading = ProgressDialog(mActivity)
        }
        loading.show()
        Log.e("BaseFragment:", "loading is showing")
    }

    override fun dismissLoading() {
        if (::loading.isInitialized && loading.isShowing) {
            loading.dismiss()
        }
        Log.e("BaseFragment:", "loading is dismissed")
    }
}