package com.example.common.base.activity

import android.os.Bundle
import androidx.databinding.DataBindingUtil
import androidx.databinding.ViewDataBinding
import com.example.common.base.viewmodel.BaseViewModel

/**
 * <pre>
 *     author : louis wang
 *     time   : 2020/06/22
 *     desc   : 包含ViewModel和Databinding的Activity基类
 *     version: 1.0
 * </pre>
 */
abstract class BaseVmDbActivity<VM : BaseViewModel, DB : ViewDataBinding> : BaseVmActivity<VM>() {

    lateinit var mDataBind: DB

    override fun onCreate(savedInstanceState: Bundle?) {
        userDataBinding(true)
        super.onCreate(savedInstanceState)
    }

    /**
     * 创建DataBinding
     */
    override fun initDataBind() {
        mDataBind = DataBindingUtil.setContentView(this, layoutId())
        mDataBind.lifecycleOwner = this
    }

    override fun onDestroy() {
        super.onDestroy()
        if (::mDataBind.isInitialized) {
            mDataBind.unbind()
        }
    }

}