package com.example.common.network

import okhttp3.OkHttpClient
import retrofit2.Retrofit

/**
 * <pre>
 *     author : louis wang
 *     time   : 2020/06/22
 *     desc   : 网络请求构建器基类
 *     version: 1.0
 * </pre>
 */
abstract class BaseNetworkApi {
    fun <T> getApi(serverClass: Class<T>, baseUrl: String): T {
        val retrofitBuilder = Retrofit.Builder()
                .baseUrl(baseUrl)
                .client(okHttpClient)
        return setRetrofitBuilder(retrofitBuilder).build().create(serverClass)
    }

    /**
     * 实现重写父类的setHttpClientBuilder方法，
     * 在这里可以添加拦截器，可以对 OkHttpClient.Builder 做任意操作
     */
    abstract fun setHttpClientBuilder(builder: OkHttpClient.Builder): OkHttpClient.Builder

    /**
     * 实现重写父类的setRetrofitBuilder方法，
     * 在这里可以对Retrofit.Builder做任意操作，比如添加GSON解析器，Protocol
     */
    abstract fun setRetrofitBuilder(builder: Retrofit.Builder): Retrofit.Builder

    /**
     * 配置http
     */
    private val okHttpClient: OkHttpClient
        get() {
            var builder = OkHttpClient.Builder()
            builder = setHttpClientBuilder(builder)
            return builder.build()
        }
}