package com.example.common.network.error

import java.net.ConnectException
import java.net.SocketTimeoutException
import java.net.UnknownHostException

/**
 * <pre>
 *     author : louis wang
 *     time   : 2020/06/22
 *     desc   :  根据异常返回相关的错误信息
 *     version: 1.0
 * </pre>
 */
object ExceptionHandle {

    fun handleException(e: Throwable?): AppException {
        return when (e) {
            is UnknownHostException -> AppException(Error.ERROR_NET, e)
            is ConnectException -> AppException(Error.ERROR_CONNECT, e)
            is SocketTimeoutException -> AppException(Error.ERROR_TIMEOUT, e)
            is ServerException -> AppException(Error.ERROR_SERVER, e)
            is NullPointerException -> AppException(Error.ERROR_DATA, e)
            else -> AppException(Error.ERROR_UNKNOWN, e)
        }
    }
}